/*-------------------------------------------------------------------------
 *	$Id: mgd77_IGF_coeffs.h,v 1.4 2007/01/30 20:37:09 pwessel Exp $
 * 
 *    Copyright (c) 2005-2007 by P. Wessel
 *    See README file for copying and redistribution conditions.
 */
 
#define MGD77_IGF24_G0	978052.0
#define MGD77_IGF30_G0	978049.0
#define MGD77_IGF67_G0	978031.846
#define MGD77_IGF80_G0	978032.67714
#define MGD77_IGF24_G1	0.005285
#define MGD77_IGF30_G1	0.0052884
#define MGD77_IGF67_G1	0.0053024
#define MGD77_IGF80_G1	0.00193185138639
#define MGD77_IGF24_G2	7e-6
#define MGD77_IGF30_G2	0.0000059
#define MGD77_IGF67_G2	0.0000058
#define MGD77_IGF80_G2	0.00669437999013
#define MGD77_IGF24_G3	27e-6
